@@ -61,10 +61,10 @@ sub generate_conf {
             HAVE_SYS_SOCKET_H    sys/socket.h
             HAVE_SYS_SOCKIO_H    sys/sockio.h
             HAVE_SYS_STAT_H      sys/stat.h
-            HAVE_SYS_TIME_H      sys/time.h
+            -HAVE_SYS_TIME_H      sys/time.h
             HAVE_SYS_TYPES_H     sys/types.h
             HAVE_SYS_WAIT_H      sys/wait.h
-            HAVE_TIME_H          time.h
+            -HAVE_TIME_H          time.h
             HAVE_UNISTD_H        unistd.h
             HAVE_WINDOWS_H       Windows.h
         ));
@@ -77,13 +77,9 @@ sub generate_conf {
         #try_getentropy   ($check, \$longest, $defines);
         #try_getrandom    ($check, \$longest, $defines);
         try_lstat        ($check, \$longest, $defines);
-        try_precise      ($check, \$longest, $defines);
         try_sa_len       ($check, \$longest, $defines);
         try_symlink      ($check, \$longest, $defines);
         #try_threads      ($check, \$longest, $defines);
-
-        # do this last, just to be safe.
-        try_u64          ($check, \$longest, $defines);
     }
 #
 # these havent been handled yet. do they need to be?
@@ -409,74 +405,6 @@ sub try_threads {
     unlink $conf1, $conf2;
 }
 
-sub try_precise {
-    my ($check, $long, $defs) = @_;
-    my $msg = 'Checking precise systime';
-    my $len = length $msg;
-    if ($check) { $$long = $len if $len > $$long; return; }
-    my $more = $$long - $len;
-    my $conf = gen_confh($defs);
-
-    my $Werror = $WIN32 ? '-WX'  : '-Werror';
-    my $lib    = $WIN32 ? 'ucrt' : 'c';
-
-    if ( check_lib(
-        header   => $conf,
-        lib      => $lib,
-        ccflags  => "-I. $Werror",
-        debug    => 0,
-        function => q{
-            FILETIME  file_time;
-            GetSystemTimePreciseAsFileTime( &file_time );
-            return 0;
-        },
-    )) {
-        push @$defs, '#define HAVE_PRECISE_SYSTIME 1';
-        print $msg, ' ..', '.'x$more, ' found';
-    }
-    else {
-        push @$defs, '#undef HAVE_PRECISE_SYSTIME';
-        print $msg, ' ..', '.'x$more, ' missing';
-    }
-    unlink $conf;
-}
-
-sub try_u64 {
-    my ($check, $long, $defs) = @_;
-    my $msg = 'Checking U64 type';
-    my $len = length $msg;
-    if ($check) { $$long = $len if $len > $$long; return; }
-    my $more = $$long - $len;
-
-    my ($conf, $fh) = gen_confh_fh($defs);
-    print $fh join("\n", map {s/^\s+//;$_} split(/\n/, q{
-        #include "EXTERN.h"
-        #include "perl.h"
-    }));
-    close $fh;
-
-    if ( check_lib(
-        header   => $conf,
-        lib      => 'c', # always do at least this
-        incpath  => ['.', File::Spec->catdir($Config{archlib}, 'CORE')],
-        #ccflags  => '-Wno-compound-token-split-by-macro',
-        debug    => 0,
-        function => q{
-            U64 x;
-            x = 0;
-            return x;
-        },
-    )) {
-        push @$defs, '#define HAVE_TYPE_U64 1';
-        print $msg, ' ..', '.'x$more, ' found';
-    }
-    else {
-        push @$defs, '#undef HAVE_TYPE_U64';
-        print $msg, ' ..', '.'x$more, ' missing';
-    }
-    unlink $conf;
-}
-
 sub write_conf {
     my ($defines, $outfile) = @_;
 
