@@ -42,29 +42,6 @@ extern "C" {
   (p)[3] = (((_v) >> 24) & 0xFFU); \
 } while (0)
 
-
-#define STATESZ  16        /* words: 4 constant, 8 key, 2 counter, 2 nonce */
-#define KEYSZ    40        /* bytes of user supplied key+nonce */
-#define CORESZ   64        /* bytes output by core */
-#define BUFSZ    16*CORESZ /* bytes we get at a time (1024) */
-#define ROUNDS   20
-
-#ifdef USE_WIN32_NATIVE
-typedef __declspec(align (8)) struct {
-#else
-typedef struct {
-#endif
-  U32     state[STATESZ];
-  UCHAR   buf[BUFSZ];
-  U16     have;
-#ifdef USE_WIN32_NATIVE
-} cc_struct_t;
-#else
-} cc_struct_t __attribute__ ((aligned (8)));
-#endif
-
-static cc_struct_t cc;
-
 /* perls ROTL32 broken too */
 #define rotl32(x,r) ((((U32)(x)) << (r)) | (((U32)(x)) >> (32 - (r))))
 
@@ -75,8 +52,9 @@ static cc_struct_t cc;
   c += d; b = rotl32(b ^ c,  7);
 
 
-static void cc_init(const UCHAR *seed, IV init_buffer) {
-  U32 *x = (U32*)&cc.state;
+static void cc_init(pUCXT, const UCHAR *seed, IV init_buffer) {
+  cc_st *cc = &UCXT.cc;
+  U32 *x = (U32*)&cc->state;
 
   x[ 0] = 0x61707865;
   x[ 1] = 0x3320646e;
@@ -96,18 +74,19 @@ static void cc_init(const UCHAR *seed, IV init_buffer) {
   x[15] = U8TO32_LE(seed + 36);
 
   if (init_buffer) {
-    memset(cc.buf, 0, BUFSZ);
-    cc.have = 0;
+    memset(cc->buf, 0, CC_BUFSZ);
+    cc->have = 0;
   }
 }
 
-static void cc_core(UCHAR* buf) {
-  U32 *s = cc.state;
+static void cc_core(pUCXT, UCHAR* buf) {
+  cc_st *cc = &UCXT.cc;
+  U32 *s = cc->state;
   U32 i, x[16];
 
   memcpy(x, s, 16*sizeof(U32));
 
-  for (i = 0; i<ROUNDS; i+=2) {
+  for (i = 0; i<CC_ROUNDS; i+=2) {
     QROUND( x[ 0], x[ 4], x[ 8], x[12] );
     QROUND( x[ 1], x[ 5], x[ 9], x[13] );
     QROUND( x[ 2], x[ 6], x[10], x[14] );
@@ -128,27 +107,28 @@ static void cc_core(UCHAR* buf) {
   if (++s[12] == 0) s[13]++;
 }
 
-static U16 cc_stream(UCHAR* buf, U16 n) {
+static U16 cc_stream(pUCXT, UCHAR* buf, U16 n) {
   U16   r = n;
-  UCHAR sbuf[CORESZ];
+  UCHAR sbuf[CC_CORESZ];
 
-  while (r >= CORESZ) {
-    cc_core(buf);
-    buf += CORESZ;
-    r -= CORESZ;
+  while (r >= CC_CORESZ) {
+    cc_core(aUCXT, buf);
+    buf += CC_CORESZ;
+    r -= CC_CORESZ;
   }
   if (r > 0) {
-    cc_core(sbuf);
+    cc_core(aUCXT, sbuf);
     memcpy(buf, sbuf, r);
   }
   return n;
 }
 
-static U32 cc_refill() {
+static U32 cc_refill(pUCXT) {
+  cc_st *cc = &UCXT.cc;
   U64   *cp;
 
   /* refill buffer */
-  cc.have = cc_stream((UCHAR*)&cc.buf, BUFSZ);
+  cc->have = cc_stream(aUCXT, (UCHAR*)&cc->buf, CC_BUFSZ);
 
   /* reseed with KEYSZ bytes from buffer, then zero */
   /*
@@ -180,68 +160,72 @@ static U32 cc_refill() {
   */
 
   /* salt the buffer */
-  cp = (U64*)&cc.buf;
-  while (cp < (U64*)&cc.have)
-    *cp++ ^= xo_rand();
-  return cc.have;
+  cp = (U64*)&cc->buf;
+  while (cp < (U64*)&cc->have)
+    *cp++ ^= xo_rand(aUCXT);
+  return cc->have;
 }
 
 /* API */
 
-void cc_srand(void) {
+void cc_srand(pUCXT) {
   U64     *cp;
   UCHAR   data[40];
 
-  xo_srand();
+  xo_srand(aUCXT);
 
   cp = (U64*)&data;
 
-  *cp++ = xo_rand();
-  *cp++ = xo_rand();
-  *cp++ = xo_rand();
-  *cp++ = xo_rand();
-  *cp++ = xo_rand();
+  *cp++ = xo_rand(aUCXT);
+  *cp++ = xo_rand(aUCXT);
+  *cp++ = xo_rand(aUCXT);
+  *cp++ = xo_rand(aUCXT);
+  *cp++ = xo_rand(aUCXT);
 
-  cc_init(data, 1);
+  cc_init(aUCXT, data, 1);
 }
 
-void cc_rand16(U16 *out) {
+void cc_rand16(pUCXT, U16 *out) {
+  cc_st *cc = &UCXT.cc;
   UCHAR *ptr;
 
-  if (cc.have < 2) cc_refill();
-  ptr = cc.buf + BUFSZ - cc.have;
-  cc.have -= 2;
+  if (cc->have < 2) cc_refill(aUCXT);
+  ptr = cc->buf + CC_BUFSZ - cc->have;
+  cc->have -= 2;
 
   *out = U8TO16_LE(ptr);
 }
 
-void cc_rand32(U32 *out) {
+void cc_rand32(pUCXT, U32 *out) {
+  cc_st *cc = &UCXT.cc;
   UCHAR *ptr;
 
-  if (cc.have < 4) cc_refill();
-  ptr = cc.buf + BUFSZ - cc.have;
-  cc.have -= 4;
+  if (cc->have < 4) cc_refill(aUCXT);
+  ptr = cc->buf + CC_BUFSZ - cc->have;
+  cc->have -= 4;
 
   *out = U8TO32_LE(ptr);
 }
 
-void cc_rand64(U64 *out) {
+void cc_rand64(pUCXT, U64 *out) {
+  cc_st *cc = &UCXT.cc;
   UCHAR *ptr;
 
-  if (cc.have < 8) cc_refill();
-  ptr = cc.buf + BUFSZ - cc.have;
-  cc.have -= 8;
+  if (cc->have < 8) cc_refill(aUCXT);
+  ptr = cc->buf + CC_BUFSZ - cc->have;
+  cc->have -= 8;
 
   *out = U8TO64_LE(ptr);
 }
 
-void cc_rand128(void *out) {
+void cc_rand128(pUCXT, void *out) {
+  cc_st *cc = &UCXT.cc;
   U64   a, b;
   UCHAR *ptr;
 
-  if (cc.have < 16) cc_refill();
-  ptr = cc.buf + BUFSZ - cc.have;
-  cc.have -= 16;
+  if (cc->have < 16) cc_refill(aUCXT);
+  ptr = cc->buf + CC_BUFSZ - cc->have;
+  cc->have -= 16;
 
   a = U8TO64_LE(ptr);
   b = U8TO64_LE(ptr);
