@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-void uu_clear(struct uu *io) {
+void uu_clear(pUCXT, struct uu *io) {
   io->time_low              = 0;
   io->time_mid              = 0;
   io->time_high_and_version = 0;
