@@ -3,7 +3,7 @@
 
 #include "uulib/UUID.h"
 
-void uu_clear(struct uu *io);
+void uu_clear(pUCXT, struct uu *io);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
