@@ -17,31 +17,52 @@ extern "C" {
 #endif
 #undef open
 
+/*
 static int        state_fd = -2;
 static FILE       *state_f = NULL;
 static const char *statepath = NULL;
+*/
 
-void uu_init_statepath(const char *path) {
+#define state_fd    UCXT.clock_state_fd
+#define state_f     UCXT.clock_state_f
+#define statepath   UCXT.clock_state_path
+#define adjustment  UCXT.clock_adj
+#define last        UCXT.clock_last
+#define clock_seq   UCXT.clock_seq
+
+/* called at boot */
+void uu_clock_init(pUCXT) {
+  state_fd   = -2;
+  state_f    = NULL;
+  statepath  = NULL;
+  adjustment = 0;
+  last.tv_sec = 0;
+  last.tv_usec = 0;
+  /* clock_seq uninit */
+}
+
+void uu_init_statepath(pUCXT, const char *path) {
   if (state_fd >= 0)
     fclose(state_f);
   state_fd  = -2;
-  statepath = path;
+  statepath = (char*)path;
 }
 
 /* returns 100ns intervals since unix epoch.
 *  since gettimeofday() is in 1usec intervals,
 *  last digit is simulated via adjustment.
 */
-IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
-  static int            adjustment = 0;
-  static struct timeval last = {0, 0};
-  static U16            clock_seq;
+IV uu_clock(pUCXT, U64 *clock_reg, U16 *ret_clock_seq) {
+  //static int            adjustment = 0;
+  //static struct timeval last = {0, 0};
+  //static U16            clock_seq;
   struct timeval        tv;
 #ifdef HAVE_LSTAT
   struct stat           statbuf;
 #endif
   mode_t                save_umask;
   int                   len;
+  UV                    ptod[2];
 
   if (state_fd == -2) {
 #ifdef HAVE_LSTAT
@@ -86,13 +107,22 @@ IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
   }
 
   if ((last.tv_sec == 0) && (last.tv_usec == 0)) {
-    cc_rand16(&clock_seq);
+    cc_rand16(aUCXT, &clock_seq);
     clock_seq &= 0x3fff;
-    gettimeofday(&last, 0);
+
+    /* gettimeofday(&last, 0); */
+    (*UCXT.myU2time)(aTHX_ (UV*)&ptod);
+    last.tv_sec  = ptod[0];
+    last.tv_usec = ptod[1];
+
     last.tv_sec--;
   }
 
-  gettimeofday(&tv, 0);
+  /* gettimeofday(&tv, 0); */
+  (*UCXT.myU2time)(aTHX_ (UV*)&ptod);
+  tv.tv_sec  = ptod[0];
+  tv.tv_usec = ptod[1];
+
   if ((tv.tv_sec < last.tv_sec) || ((tv.tv_sec == last.tv_sec) && (tv.tv_usec < last.tv_usec))) {
     clock_seq = (clock_seq+1) & 0x3fff;
     adjustment = 0;
