@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-void uu_copy_binary(const uu_t in, uu_t out) {
+void uu_copy_binary(pUCXT, const uu_t in, uu_t out) {
   U8  *cp1 = (U8*)&in;
   U8  *cp2 = out;
   UV  i;
@@ -17,7 +17,7 @@ void uu_copy_binary(const uu_t in, uu_t out) {
     *cp1++ = *cp2++;
 }
 
-void uu_copy_struct(const struct uu *in, struct uu *out) {
+void uu_copy_struct(pUCXT, const struct uu *in, struct uu *out) {
   out->time_low = in->time_low;
   out->time_mid = in->time_mid;
   out->time_high_and_version = in->time_high_and_version;
