@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-IV uu_isnull_binary(const uu_t in)
+IV uu_isnull_binary(pUCXT, const uu_t in)
 {
   const U8  *cp = in;
   IV        i;
@@ -19,7 +19,7 @@ IV uu_isnull_binary(const uu_t in)
   return 1;
 }
 
-IV uu_isnull_struct(const struct uu *in) {
+IV uu_isnull_struct(pUCXT, const struct uu *in) {
   if (in->time_low)              return 0;
   if (in->time_mid)              return 0;
   if (in->time_high_and_version) return 0;
