@@ -3,8 +3,8 @@
 
 #include "uulib/UUID.h"
 
-IV uu_isnull_binary(const uu_t in);
-IV uu_isnull_struct(const struct uu *in);
+IV uu_isnull_binary(pUCXT, const uu_t in);
+IV uu_isnull_struct(pUCXT, const struct uu *in);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
