@@ -56,7 +56,7 @@ extern "C" {
  * commenting out get_node_id just to get gen_uuid to compile under windows
  * is not the right way to go!
  */
-static int get_node_id(unsigned char *node_id)
+static int get_node_id(pUCXT, unsigned char *node_id)
 {
 #ifdef HAVE_NET_IF_H
 	int 		sd;
@@ -144,13 +144,13 @@ static int get_node_id(unsigned char *node_id)
 	return 0;
 }
 
-int uu_get_node_id(U8 *node_id) {
+int uu_get_node_id(pUCXT, U8 *node_id) {
   /* returns:
    *  -1 if cant find due to error.
    *   0 if cant find.
    *   1 if found.
   */
-  return get_node_id(node_id);
+  return get_node_id(aUCXT, node_id);
 }
 
 /* ex:set ts=2 sw=2 itab=spaces: */
