@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-void uu_pack(const struct uu *in, uu_t out) {
+void uu_pack(pUCXT, const struct uu *in, uu_t out) {
   U32 tmp;
   //U8  *out = ptr;
 
@@ -33,7 +33,7 @@ void uu_pack(const struct uu *in, uu_t out) {
   memcpy(out+10, in->node, 6);
 }
 
-void uu_pack4(const struct uu4 *in, uu_t out) {
+void uu_pack4(pUCXT, const struct uu4 *in, uu_t out) {
   U32 tmp;
 
   tmp = in->rand_a;
@@ -61,7 +61,7 @@ void uu_pack4(const struct uu4 *in, uu_t out) {
   out[12] = (U8)tmp;
 }
 
-void uu_pack6(const struct uu6 *in, uu_t out) {
+void uu_pack6(pUCXT, const struct uu6 *in, uu_t out) {
   U32 tmp;
 
   tmp = in->time_high;
@@ -85,7 +85,7 @@ void uu_pack6(const struct uu6 *in, uu_t out) {
   memcpy(out+10, in->node, 6);
 }
 
-void uu_pack7(const struct uu7 *in, uu_t out) {
+void uu_pack7(pUCXT, const struct uu7 *in, uu_t out) {
   U64 tmp;
 
   tmp = in->time_high;
