@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-IV uu_parse(const char *in, struct uu *out) {
+IV uu_parse(pUCXT, const char *in, struct uu *out) {
   int         i;
   const char  *cp;
   char        buf[3];
