@@ -3,7 +3,7 @@
 
 #include "uulib/UUID.h"
 
-IV uu_parse(const char *in, struct uu *out);
+IV uu_parse(pUCXT, const char *in, struct uu *out);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
