@@ -3,8 +3,8 @@
 
 #include "uulib/UUID.h"
 
-void sm_srand(void);
-U64  sm_rand(void);
+void sm_srand(pUCXT);
+U64  sm_rand(pUCXT);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
