@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-void uu_unpack(const uu_t in, struct uu *out) {
+void uu_unpack(pUCXT, const uu_t in, struct uu *out) {
   const U8  *ptr = in;
   U32       tmp;
 
