@@ -3,7 +3,7 @@
 
 #include "uulib/UUID.h"
 
-void uu_unpack(const uu_t in, struct uu *out);
+void uu_unpack(pUCXT, const uu_t in, struct uu *out);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
