@@ -15,17 +15,20 @@ extern "C" {
 
 #define xo_rotl(x,k) (((x) << (k)) | ((x) >> (64 - (k))))
 
-static U64 xo_s[4];
+/* called from boot */
+void xo_srand(pUCXT) {
+  U64 *xo_s = UCXT.xo_s;
 
-void xo_srand(void) {
-  sm_srand();
-  xo_s[0] = sm_rand();
-  xo_s[1] = sm_rand();
-  xo_s[2] = sm_rand();
-  xo_s[3] = sm_rand();
+  sm_srand(aUCXT);
+  xo_s[0] = sm_rand(aUCXT);
+  xo_s[1] = sm_rand(aUCXT);
+  xo_s[2] = sm_rand(aUCXT);
+  xo_s[3] = sm_rand(aUCXT);
 }
 
-U64 xo_rand(void) {
+U64 xo_rand(pUCXT) {
+  U64 *xo_s = UCXT.xo_s;
+
   const U64 result = xo_rotl(xo_s[0] + xo_s[3], 23) + xo_s[0];
 
   const U64 t = xo_s[1] << 17;
