@@ -3,8 +3,8 @@
 
 #include "uulib/UUID.h"
 
-void xo_srand(void);
-U64  xo_rand(void);
+void xo_srand(pUCXT);
+U64  xo_rand(pUCXT);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
